/*
 * massive_occlusion_layer.sl - all-in-one ambient occlusion pass for Massive
 *   implemented as a volume shader which can be assigned as the Atmosphere
 *   shader for an object, providing an occlusion output w/o requiring modification
 *   of the surface shaders
 *
 * HISTORY
 *
 *   2010-Nov-9:  converted from massive_occlusionpass surface shader
 *
 *  (c) 2010 SiTex Graphics, Inc.
 */

volume massive_occlusion_layer(
   float invert = 0;

   float samples = 256;
   float maxhitdist = 500;
   float maxerror = 0.0;

   float shadowbias = 0.1;
   float coneangle = 1.57;

   string shadowgroups = "";

   output varying normal Nunoccl = 0;
   output varying color __occlusion = 0;
  )
{
  normal Nf;
  color o;

  Nf = faceforward(normalize(N), I);

  if (shadowgroups!="")
    o = occlusion (P, Nf, coneangle, Nunoccl, "samples", samples, "maxhitdist", maxhitdist,
                   "maxerror", maxerror, "bias", shadowbias, "maxpixeldist", 0, "subset", shadowgroups);

  else
    o = occlusion (P, Nf, coneangle, Nunoccl, "samples", samples, "maxhitdist", maxhitdist,
                   "maxerror", maxerror, "bias", shadowbias, "maxpixeldist", 0);

  if (invert==1) o=1-o;

  __occlusion = o;
}

